// THIS PROGRAM RUNS PROCEDURES FOR IMPACT PAPER's Reproduceability Package///
// DATE CREATED: 2024-11-1
// AUTHOR: Euijin Jung (ejung1@worldbank.org)

*************************************************************************

clear all
set more off
global main "C:\Temp\Reproducibility Package of Exposure to Climate Policies paper_final"
global data "Data\Dashboard_rawdata.xlsx"
global gdp  "Data\GDP.dta"
global wb_class "Data\ISO_Region_Income.dta"
sysdir set PLUS  "$main\ado"
set varabbrev on
cd "$main\"

**fossil fuel exports***

import excel "$data", sheet("ff") firstrow clear
gen sec="Fossil fuels"
tostring ProductCode, replace
tempfile tmp
save `tmp', replace

*critical mineral exports***
import excel "$data", sheet("cm") firstrow clear
gen sec="Critical minerals"
tostring ProductCode, replace
append using `tmp'
save `tmp', replace

**EV exports***
import excel "$data", sheet("ev") firstrow clear
gen sec="EV"
tostring ProductCode, replace
append using `tmp'
save `tmp', replace

**EV components exports***
import excel "$data", sheet("ev comp") firstrow clear
gen sec="EV components"
tostring ProductCode, replace
append using `tmp'
save `tmp', replace

**battery exports***
import excel "$data", sheet("battery") firstrow clear
gen sec="Battery"
tostring ProductCode, replace
append using `tmp'
save `tmp', replace

***renewables exports***
import excel "$data", sheet("renewable") firstrow clear
gen sec="Renewable"
tostring ProductCode, replace
append using `tmp'
save `tmp', replace

*** EUDR related agricutural exports***
import excel "$data", sheet("eudr") firstrow clear
gen sec="Ag(EUDR)"
tostring ProductCode, replace
append using `tmp'
save `tmp', replace


*** region and income variables***
replace PartnerISO3="COD" if PartnerISO3=="ZAR"
replace PartnerISO3="ROU" if PartnerISO3=="ROM"
replace PartnerISO3="TWN" if PartnerISO3=="OAS"
replace PartnerISO3="SRB" if PartnerISO3=="SER"
replace PartnerISO3="TLS" if PartnerISO3=="TMP"
replace PartnerISO3="SDN" if PartnerName=="Sudan"
replace PartnerISO3="MNE" if PartnerISO3=="MNT"
drop PartnerName PartnerIncomeGroup PartnerRegion

merge m:1 PartnerISO3 using "$wb_class"
order  _m
so _m PartnerISO3
keep if _m==3
drop _m Product Products VC
order ReporterISO3 ReporterName PartnerISO3 PartnerName sec TradeValuein1000USD
egen sec_gr=group(sec)
so sec_gr
so PartnerIncomeGroup

**keeping developing countries only and dropping EU, China and US****
drop if PartnerIncomeGroup=="High income"
drop if PartnerISO3=="CHN"|PartnerISO3=="USA"

***zeroing exports of EU members to EU***
gen i_c=lower(PartnerISO3)
gen eu=0
replace eu=1 if i_c=="aut" | i_c =="bel" | i_c =="bgr" | i_c =="hrv"| i_c =="cyp"| i_c =="cze"| i_c =="dnk"| i_c =="est"| i_c =="fin"| i_c =="fra"| i_c =="deu"| i_c =="grc"| i_c =="hun" | i_c =="irl"| i_c =="ita"| i_c =="lva"| i_c =="ltu"| i_c =="lux"| i_c =="mlt" | i_c =="nld"| i_c =="pol"| i_c =="prt"| i_c =="rou"| i_c =="svk"| i_c =="svn"| i_c =="esp"| i_c =="swe"
drop i_c eu
save "$main\Data\data_v1.dta", replace

****generating economic and sector exposure***
preserve
egen reg=group( ReporterISO3)
collapse(sum) TradeValuein1000USD, by ( PartnerISO3 PartnerName PartnerRegion PartnerIncomeGroup sec sec_gr reg )
reshape wide (Trade) , i( PartnerISO3 sec)j(reg)
egen cheuus= rowtotal(TradeValuein1000USD2  TradeValuein1000USD3 TradeValuein1000USD4)
rename TradeValuein1000USD1  wld
rename TradeValuein1000USD2 chn
rename TradeValuein1000USD3 eu
rename TradeValuein1000USD4 us
gen RoW= wld-cheuus
merge m:1 PartnerISO3 using "$gdp"
keep if _m==3
drop _m Latestyear Source


***index2=sector exposure; index3=economic exposure & select top 14 countries***
gen index2= cheuus/ wld*100
gen index3=che/GDP*100
bysort sec_gr: egen rank=rank(- index3),track
so sec rank
rename index2 sector_exposure
rename index3 economic_exposure
keep if rank<15

tempfile figure
save `figure', replace
restore

use `figure'
order sec sec_gr PartnerName sector_exposure economic_exposure
keep PartnerName sec sector_exposure economic_exposure rank sec_gr sec

preserve
keep if sec_gr==1
so rank
export excel "$main\Data for figures\data for figures_v1.xlsx", sheet("eudr",replace) firstrow (variables)
restore
preserve
keep if sec_gr==2
so rank
export excel "$main\Data for figures\data for figures_v1.xlsx", sheet("battery",replace) firstrow (variables)
restore
preserve
keep if sec_gr==3
so rank
export excel "$main\Data for figures\data for figures_v1.xlsx", sheet("cm",replace) firstrow (variables)
restore
preserve
keep if sec_gr==4
so rank
export excel "$main\Data for figures\data for figures_v1.xlsx", sheet("ev",replace) firstrow (variables)
restore
preserve
keep if sec_gr==5
so rank
export excel "$main\Data for figures\data for figures_v1.xlsx", sheet("ev comp",replace) firstrow (variables)
restore
preserve
keep if sec_gr==6
so rank
export excel "$main\Data for figures\data for figures_v1.xlsx", sheet("ff",replace) firstrow (variables)
restore
preserve
keep if sec_gr==7
so rank
export excel "$main\Data for figures\data for figures_v1.xlsx", sheet("renewable",replace) firstrow (variables)
restore
clear








